﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGanttView;

using nsTLV = Infragistics.Win.UltraWinSchedule.TimelineView;

namespace TimelineViewTesting
{
    #region TimeSlotBorderCreationFilter
    /// <summary>
    /// IUIElementCreationFilter implementation used to draw a vertical line
    /// alongside the beginning of the first time slot for the current date.
    /// </summary>
    public class TimeSlotBorderCreationFilter : IUIElementCreationFilter
    {
        #region Members
        private VideoFrameTimeSlotUIElement verticalLineElement = null;
        private AppearanceBase appearance = null;
        #endregion Members

        #region IUIElementCreationFilter

        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            //  Get a reference to the UIElement which contains the time slot elements.
            nsTLV.ActivityAreaUIElement activityAreaElement = parent as nsTLV.ActivityAreaUIElement;

            if ( activityAreaElement != null )
            {
                //  Use GetDescendant to find the time slot for the current date
                nsTLV.TimeSlotUIElement currentDateFirstSlot =
                    taskAreaElement.GetDescendant( typeof(nsTLV.TimeSlotUIElement), DateTime.Today ) as
                    nsTLV.TimeSlotUIElement;

                if ( currentDateFirstSlot != null )
                {
                    //  Create the Appearance if its null
                    if ( this.appearance == null )
                    {
                        this.appearance = new Infragistics.Win.Appearance();

                        //  There are a million and one orange Office2k7 colors, use one of them
                        this.appearance.BorderColor = Office2007ColorTable.Colors.OutlookNavPaneHotGroupHeaderGradientDark;
                    }

                    //  Create the VideoFrameTimeSlotUIElement if its null, initialize it if its not null
                    if ( this.verticalLineElement == null )
                        this.verticalLineElement = new VideoFrameTimeSlotUIElement( taskAreaElement, UIElementBorderStyle.Solid, this.appearance );
                    else
                        this.verticalLineElement.Initialize( UIElementBorderStyle.Solid, this.appearance );

                    //  Set the bounds of the VideoFrameTimeSlotUIElement
                    Rectangle rect = currentDateFirstSlot.Rect;
                    rect.Width = DrawUtility.CalculateBorderWidths(UIElementBorderStyle.Solid).Left;
                    this.verticalLineElement.Rect = rect;

                    //  Add the VideoFrameTimeSlotUIElement to the TaskAreaUIElement's ChildElements collection.
                    taskAreaElement.ChildElements.Add( this.verticalLineElement );
                }
            }
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }

        #endregion IUIElementCreationFilter
    }
    #endregion TimeSlotBorderCreationFilter

}